@@ -16,7 +16,8 @@ class _Iterative(_CCA_Base):
 
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, deflation='cca', max_iter: int = 100,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True, deflation='cca',
+                 max_iter: int = 100,
                  generalized: bool = False,
                  initialization: str = 'unregularized', tol: float = 1e-9):
         """
@@ -30,7 +31,7 @@ class _Iterative(_CCA_Base):
         :param initialization: intialization for optimisation. 'unregularized' uses CCA or PLS solution,'random' uses random initialization,'uniform' uses uniform initialization of weights and scores
         :param tol: if the cosine similarity of the weights between subsequent iterations is greater than 1-tol the loop is considered converged
         """
-        super().__init__(latent_dims=latent_dims, scale=scale)
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, accept_sparse=True)
         self.max_iter = max_iter
         self.generalized = generalized
         self.initialization = initialization
@@ -65,12 +66,12 @@ class _Iterative(_CCA_Base):
                 self.score_list[i][:, k] = self.loop.scores[i]
                 self.loading_list[i][:, k] = np.dot(self.loop.scores[i], residual)
                 # TODO This is CCA deflation (https://ars.els-cdn.com/content/image/1-s2.0-S0006322319319183-mmc1.pdf)
-                residuals[i] = self.deflate(residuals[i], self.score_list[i][:, k])
+                residuals[i] = self.deflate(residuals[i], self.score_list[i][:, k], self.weights_list[i][:, k])
             self.objective.append(self.loop.track_objective)
         self.train_correlations = self.predict_corr(*views)
         return self
 
-    def deflate(self, residual, score):
+    def deflate(self, residual, score, loading):
         """
         Deflate view residual by CCA deflation (https://ars.els-cdn.com/content/image/1-s2.0-S0006322319319183-mmc1.pdf)
 
@@ -80,6 +81,8 @@ class _Iterative(_CCA_Base):
         """
         if self.deflation == 'cca':
             return residual - np.outer(score, score) @ residual / np.dot(score, score).item()
+        elif self.deflation == 'pls':
+            return residual - np.outer(score, loading)
 
     @abstractmethod
     def set_loop_params(self):
@@ -105,7 +108,8 @@ class PLS(_Iterative):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, deflation='cca', max_iter: int = 100,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True, deflation='cca',
+                 max_iter: int = 100,
                  generalized: bool = False,
                  initialization: str = 'unregularized', tol: float = 1e-9):
         """
@@ -119,7 +123,7 @@ class PLS(_Iterative):
         :param initialization: intialization for optimisation. 'unregularized' uses CCA or PLS solution,'random' uses random initialization,'uniform' uses uniform initialization of weights and scores
         :param tol: if the cosine similarity of the weights between subsequent iterations is greater than 1-tol the loop is considered converged
         """
-        super().__init__(latent_dims=latent_dims, scale=scale, deflation=deflation, max_iter=max_iter,
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, deflation=deflation, max_iter=max_iter,
                          generalized=generalized,
                          initialization=initialization, tol=tol)
 
@@ -145,7 +149,8 @@ class ElasticCCA(_Iterative):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, deflation='cca', max_iter: int = 100,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True, deflation='cca',
+                 max_iter: int = 100,
                  generalized: bool = False,
                  initialization: str = 'unregularized', tol: float = 1e-9,
                  c: Union[List[float], float] = None,
@@ -177,7 +182,8 @@ class ElasticCCA(_Iterative):
             self.stochastic = False
             warnings.warn(
                 'Non negative constraints cannot be used with stochastic regressors. Switching to stochastic=False')
-        super().__init__(latent_dims=latent_dims, scale=scale, deflation=deflation, max_iter=max_iter,
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, deflation=deflation,
+                         max_iter=max_iter,
                          generalized=generalized,
                          initialization=initialization, tol=tol)
 
@@ -205,7 +211,8 @@ class CCA_ALS(ElasticCCA):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, max_iter: int = 100, generalized: bool = False,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True, max_iter: int = 100,
+                 generalized: bool = False,
                  initialization: str = 'random', tol: float = 1e-9, stochastic=True,
                  positive: Union[List[bool], bool] = None):
         """
@@ -235,7 +242,9 @@ class SCCA(ElasticCCA):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, c: List[float] = None, max_iter: int = 100,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True,
+                 c: Union[List[float], float] = None,
+                 max_iter: int = 100,
                  generalized: bool = False,
                  initialization: str = 'unregularized', tol: float = 1e-9, stochastic=False,
                  positive: Union[List[bool], bool] = None):
@@ -243,9 +252,10 @@ class SCCA(ElasticCCA):
         Constructor for SCCA
 
         """
-        super().__init__(latent_dims=latent_dims, max_iter=max_iter, generalized=generalized,
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, max_iter=max_iter,
+                         generalized=generalized,
                          initialization=initialization, tol=tol, c=c, l1_ratio=1, constrained=False,
-                         stochastic=stochastic, scale=scale, positive=positive)
+                         stochastic=stochastic, positive=positive)
 
 
 class PMD(_Iterative):
@@ -265,7 +275,9 @@ class PMD(_Iterative):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, c: List[float] = None, max_iter: int = 100,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True,
+                 c: Union[List[float], float] = None,
+                 max_iter: int = 100,
                  generalized: bool = False, initialization: str = 'unregularized', tol: float = 1e-9,
                  positive: Union[List[bool], bool] = None):
         """
@@ -276,8 +288,9 @@ class PMD(_Iterative):
         """
         self.c = c
         self.positive = positive
-        super().__init__(latent_dims=latent_dims, max_iter=max_iter, generalized=generalized,
-                         initialization=initialization, tol=tol, scale=scale)
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, max_iter=max_iter,
+                         generalized=generalized,
+                         initialization=initialization, tol=tol)
 
     def set_loop_params(self):
         self.loop = PMDInnerLoop(max_iter=self.max_iter, c=self.c, generalized=self.generalized,
@@ -301,7 +314,9 @@ class ParkhomenkoCCA(_Iterative):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, c: List[float] = None, max_iter: int = 100,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True,
+                 c: Union[List[float], float] = None,
+                 max_iter: int = 100,
                  generalized: bool = False, initialization: str = 'unregularized', tol: float = 1e-9):
         """
         Constructor for ParkhomenkoCCA
@@ -309,8 +324,9 @@ class ParkhomenkoCCA(_Iterative):
         :param c: l1 regularisation parameter
         """
         self.c = c
-        super().__init__(latent_dims=latent_dims, max_iter=max_iter, generalized=generalized,
-                         initialization=initialization, tol=tol, scale=scale)
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, max_iter=max_iter,
+                         generalized=generalized,
+                         initialization=initialization, tol=tol)
 
     def set_loop_params(self):
         self.loop = ParkhomenkoInnerLoop(max_iter=self.max_iter, c=self.c,
@@ -335,9 +351,11 @@ class SCCA_ADMM(_Iterative):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, c: List[float] = None, mu: List[float] = None,
-                 lam: List[float] = None,
-                 eta: List[float] = None,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True,
+                 c: Union[List[float], float] = None,
+                 mu: Union[List[float], float] = None,
+                 lam: Union[List[float], float] = None,
+                 eta: Union[List[float], float] = None,
                  max_iter: int = 100,
                  generalized: bool = False, initialization: str = 'unregularized', tol: float = 1e-9):
         """
@@ -353,8 +371,9 @@ class SCCA_ADMM(_Iterative):
         self.mu = mu
         self.lam = lam
         self.eta = eta
-        super().__init__(latent_dims=latent_dims, max_iter=max_iter, generalized=generalized,
-                         initialization=initialization, tol=tol, scale=scale)
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, max_iter=max_iter,
+                         generalized=generalized,
+                         initialization=initialization, tol=tol)
 
     def set_loop_params(self):
         self.loop = ADMMInnerLoop(max_iter=self.max_iter, c=self.c, mu=self.mu, lam=self.lam,
@@ -372,11 +391,14 @@ class SpanCCA(_Iterative):
 
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, max_iter: int = 100, generalized: bool = False,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True, max_iter: int = 100,
+                 generalized: bool = False,
                  initialization: str = 'uniform', tol: float = 1e-9, regularisation='l0',
-                 c: List[Union[float, int]] = None, rank=1, positive: Union[List[bool], bool] = None):
-        super().__init__(latent_dims=latent_dims, max_iter=max_iter, generalized=generalized,
-                         initialization=initialization, tol=tol, scale=scale)
+                 c: Union[List[Union[float, int]], Union[float, int]] = None, rank=1,
+                 positive: Union[List[bool], bool] = None):
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, max_iter=max_iter,
+                         generalized=generalized,
+                         initialization=initialization, tol=tol)
         self.c = c
         self.regularisation = regularisation
         self.rank = rank
@@ -399,15 +421,18 @@ class SWCCA(_Iterative):
 
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, max_iter: int = 500, generalized: bool = False,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True, max_iter: int = 500,
+                 generalized: bool = False,
                  initialization: str = 'uniform', tol: float = 1e-9, regularisation='l0',
-                 c: List[Union[float, int]] = None, sample_support=None, positive: Union[List[bool], bool] = None):
+                 c: Union[List[Union[float, int]], Union[float, int]] = None, sample_support=None,
+                 positive: Union[List[bool], bool] = None):
         self.c = c
         self.sample_support = sample_support
         self.regularisation = regularisation
         self.positive = positive
-        super().__init__(latent_dims=latent_dims, max_iter=max_iter, generalized=generalized,
-                         initialization=initialization, tol=tol, scale=scale)
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, max_iter=max_iter,
+                         generalized=generalized,
+                         initialization=initialization, tol=tol)
 
     def set_loop_params(self):
         self.loop = SWCCAInnerLoop(max_iter=self.max_iter, generalized=self.generalized,
