@@ -29,12 +29,12 @@ class TCCA(_CCA_Base):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, c: List[float] = None, scale=True):
+    def __init__(self, latent_dims: int = 1, scale=True, centre=True, copy_data=True, c: List[float] = None):
         """
         Constructor for TCCA
 
         """
-        super().__init__(latent_dims=latent_dims, scale=scale)
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data, accept_sparse=True)
         self.c = c
 
     def check_params(self):
@@ -90,7 +90,7 @@ class KTCCA(TCCA):
     >>> model.fit(X1,X2)
     """
 
-    def __init__(self, latent_dims: int = 1, scale: bool = True, c: List[float] = None,
+    def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True, c: List[float] = None,
                  kernel: List[Union[float, callable]] = None,
                  gamma: List[float] = None,
                  degree: List[float] = None, coef0: List[float] = None,
@@ -105,7 +105,7 @@ class KTCCA(TCCA):
         :param kernel_params: list of additional parameters (keyword arguments) for kernel function passed as callable object.
         :param eps: epsilon value to ensure stability
         """
-        super().__init__(latent_dims=latent_dims, scale=scale)
+        super().__init__(latent_dims=latent_dims, scale=scale, centre=centre, copy_data=copy_data)
         self.kernel_params = kernel_params
         self.gamma = gamma
         self.coef0 = coef0
